@@ -24,7 +24,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: UploadItem.h 425 2005-07-03 16:20:20Z svn $
+ * $Id: UploadItem.h 466 2005-07-17 05:11:07Z svn $
  *****************************************************************************/
 
 #ifndef UPLOADITEM_H
@@ -42,7 +42,7 @@
 using namespace std;
 
 /**
- * åץɥƥɽ饹
+ * @brief åץɥƥɽ饹
  */
 class UploadItem
 {
@@ -77,7 +77,7 @@ public:
     } header;
 
     UploadItem(apr_pool_t *pool, const char *file_path, header *header);
-    UploadItem(apr_pool_t *pool);
+    explicit UploadItem(apr_pool_t *pool);
     header *set_data(const char *file_path, header *header);
     header *get_header();
     const char *get_file_path();
@@ -106,8 +106,8 @@ private:
     static const apr_size_t MAX_TIME_LENGTH;
     static const char TIME_FORMAT[];
 
-    UploadItem(const UploadItem &);
-    UploadItem &operator=(const UploadItem &);
+    UploadItem(const UploadItem&);
+    UploadItem &operator=(const UploadItem&);
 
     apr_pool_t * const pool_;
     const char *file_path_;
