@@ -24,7 +24,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: UploadItemList.h 354 2005-05-07 23:20:20Z svn $
+ * $Id: UploadItemList.h 466 2005-07-17 05:11:07Z svn $
  *****************************************************************************/
 
 #ifndef UPLOADITEMLIST_H
@@ -47,7 +47,7 @@
 using namespace std;
 
 /**
- * åץɥƥδԤ饹
+ * @brief åץɥƥδԤ饹
  */
 class UploadItemList
 {
@@ -65,10 +65,18 @@ public:
         }
     };
 
+    struct ThumbnailCompare
+    {
+        bool operator()(const string& lhs, const string& rhs) const
+        {
+            return lhs > rhs;
+        }
+    };
+
+
     UploadItemList(apr_pool_t *pool,
                    const char *file_dir, const char *thumb_dir,
                    apr_size_t total_number_limit, apr_uint64_t total_size_limit);
-    ~UploadItemList();
     void add(const char *file_path, bool is_make_thumb=false);
     apr_size_t size();
     apr_size_t thumb_size();
@@ -94,8 +102,8 @@ private:
     typedef list<string> thumb_list;
     typedef thumb_list::const_iterator thumb_iterator;
 
-    UploadItemList(const UploadItemList &);
-    UploadItemList &operator=(const UploadItemList &);
+    UploadItemList(const UploadItemList&);
+    UploadItemList &operator=(const UploadItemList&);
 
     void init();
     item_iterator begin();
@@ -108,7 +116,7 @@ private:
     const apr_size_t total_number_limit_;
     const apr_uint64_t total_size_limit_;
 
-    UploadItemReader *reader;
+    UploadItemReader reader;
     apr_uint64_t total_size_;
     apr_time_t mtime_;
     item_list ilist_;
