@@ -24,7 +24,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: BasicFileWriter.cpp 392 2005-05-15 15:33:53Z svn $
+ * $Id: BasicFileWriter.cpp 432 2005-07-07 16:59:36Z svn $
  *****************************************************************************/
 
 #include "BasicFileWriter.h"
@@ -80,7 +80,6 @@ void usage(const char *prog_name)
 
 int main(int argc, const char * const *argv)
 {
-    FileWriter *writer = NULL;
     apr_pool_t *pool;
     apr_file_t *src;
     apr_file_t *dst;
@@ -106,16 +105,14 @@ int main(int argc, const char * const *argv)
             throw "ԡΥե򳫤ޤǤ";
         }
 
-        writer = new BasicFileWriter(pool, dst);
+        BasicFileWriter writer(pool, dst);
         while (apr_file_read(src, buffer, &size) == APR_SUCCESS) {
-            writer->write(buffer, size);
+            writer.write(buffer, size);
             size = sizeof(buffer);
         }
 
         apr_file_close(dst);
         apr_file_close(src);
-
-        delete writer;
     } catch(const char *message) {
         cerr << "Error: " << message << endl;
         usage(argv[0]);
