@@ -24,7 +24,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: MmapFileWriter.cpp 392 2005-05-15 15:33:53Z svn $
+ * $Id: MmapFileWriter.cpp 461 2005-07-14 16:53:59Z svn $
  *****************************************************************************/
 
 #include "MmapFileWriter.h"
@@ -53,15 +53,14 @@ const apr_size_t MmapFileWriter::PAGE_SIZE      = MMAP_PAGE_SIZE;
  * public ᥽å
  *****************************************************************************/
 MmapFileWriter::MmapFileWriter(apr_pool_t *pool, apr_file_t *fd, apr_size_t offset)
-    : FileWriter(pool, fd)
+    : FileWriter(pool, fd),
+      file_map_(NULL),
+      size_factor_(0),
+      // ڡܿñ̤ǳƤ
+      block_size_(((BLOCK_SIZE-1)/PAGE_SIZE + 1) * PAGE_SIZE),
+      offset_(0),
+      is_closed_(false)
 {
-    // ڡܿñ̤ǳƤ
-    block_size_     = ((BLOCK_SIZE-1)/PAGE_SIZE + 1) * PAGE_SIZE;
-    size_factor_    = 0;
-    offset_         = 0;
-    file_map_       = NULL;
-    is_closed_      = false;
-
     expand();
     offset_ = offset;
 }
@@ -71,7 +70,7 @@ void MmapFileWriter::write(const void *buf, apr_size_t size)
     const char *data;
     apr_size_t write_size;
 
-    data = reinterpret_cast<const char *>(buf);
+    data = static_cast<const char *>(buf);
 
     while (size > 0) {
         write_size = (size > block_size_) ? block_size_ : size;
@@ -80,7 +79,7 @@ void MmapFileWriter::write(const void *buf, apr_size_t size)
             if (offset_ != block_size_) {
                 write_size = block_size_ - offset_;
 
-                memcpy(reinterpret_cast<char *>(file_map_->mm)+offset_, data, write_size);
+                memcpy(static_cast<char *>(file_map_->mm)+offset_, data, write_size);
                 data += write_size;
                 size -= write_size;
             }
@@ -89,7 +88,7 @@ void MmapFileWriter::write(const void *buf, apr_size_t size)
             continue;
         }
 
-        memcpy(reinterpret_cast<char *>(file_map_->mm)+offset_, data, write_size);
+        memcpy(static_cast<char *>(file_map_->mm)+offset_, data, write_size);
 
         data += write_size;
         offset_ += write_size;
@@ -172,7 +171,6 @@ void usage(const char *prog_name)
 
 int main(int argc, const char * const *argv)
 {
-    FileWriter *writer = NULL;
     apr_pool_t *pool;
     apr_file_t *src;
     apr_file_t *dst;
@@ -198,16 +196,14 @@ int main(int argc, const char * const *argv)
             throw "ԡΥե򳫤ޤǤ";
         }
 
-        writer = new MmapFileWriter(pool, dst);
+        MmapFileWriter writer(pool, dst);
         while (apr_file_read(src, buffer, &size) == APR_SUCCESS) {
-            writer->write(buffer, size);
+            writer.write(buffer, size);
             size = sizeof(buffer);
         }
 
         apr_file_close(dst);
         apr_file_close(src);
-
-        delete writer;
     } catch(const char *message) {
         cerr << "Error: " << message << endl;
         usage(argv[0]);
