@@ -24,7 +24,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: TemplateExecutor.cpp 392 2005-05-15 15:33:53Z svn $
+ * $Id: TemplateExecutor.cpp 452 2005-07-10 18:06:57Z svn $
  *****************************************************************************/
 
 #include "TemplateExecutor.h"
@@ -445,7 +445,7 @@ inline TemplateExecutor::variable *TemplateExecutor::get_var(handle *h, node *no
                 throw "Ϣɬפʾˤ¾ѿꤵƤޤ";
             }
             key = node->branch.right->branch.right->s_val;
-            var = reinterpret_cast<variable *>(apr_hash_get(var->h_val, key,
+            var = static_cast<variable *>(apr_hash_get(var->h_val, key,
                                                             APR_HASH_KEY_STRING));
         }
         break;
@@ -459,7 +459,7 @@ inline TemplateExecutor::variable *TemplateExecutor::get_var(handle *h, node *no
 
         key = h->imap->at(node->branch.right->i_val);
 
-        var = reinterpret_cast<variable *>(apr_hash_get(var->h_val, key,
+        var = static_cast<variable *>(apr_hash_get(var->h_val, key,
                                                         APR_HASH_KEY_STRING));
         break;
     default:
@@ -480,7 +480,7 @@ inline TemplateExecutor::variable *TemplateExecutor::create_variable(handle *h,
 {
     if (h->variable_pool == h->variable_pool_end) {
         h->variable_pool
-            = reinterpret_cast<variable *>(apr_palloc(h->pool,
+            = static_cast<variable *>(apr_palloc(h->pool,
                                                       sizeof(variable)*VARIABLE_POOL_NUM));
         h->variable_pool_end = h->variable_pool + VARIABLE_POOL_NUM;
     }
@@ -496,7 +496,7 @@ inline TemplateExecutor::scalar *TemplateExecutor::create_scalar(handle *h,
 {
     if (h->scalar_pool == h->scalar_pool_end) {
         h->scalar_pool
-            = reinterpret_cast<scalar *>(apr_palloc(h->pool,
+            = static_cast<scalar *>(apr_palloc(h->pool,
                                                       sizeof(scalar)*SCALAR_POOL_NUM));
         h->scalar_pool_end = h->scalar_pool + SCALAR_POOL_NUM;
     }
@@ -542,6 +542,7 @@ inline void TemplateExecutor::print(handle *h, const char *s_val)
 #include "UploadItemList.h"
 #include "mod_uploader.h"
 
+const apr_size_t TOTAL_NUMBER_LIMIT = 100;
 const apr_size_t TOTAL_SIZE_LIMIT   = 1024*1024*1024;
 
 void usage(const char *prog_name)
@@ -551,16 +552,11 @@ void usage(const char *prog_name)
 
 int main(int argc, const char * const *argv)
 {
-    TemplateParser *parser = NULL;
-    TemplateLexer *lexer = NULL;
-    TemplateExecutor *executor = NULL;
-    UploadItemList *item_list = NULL;
     apr_pool_t *pool;
     apr_file_t *fd;
     apr_mmap_t *file_map;
     apr_finfo_t info;
     TemplateParser::node *node;
-    TemplateExecutor::variable_map *vmap = NULL;
     apr_size_t ident_id;
 
     apr_app_initialize(&argc, &argv, NULL);
@@ -586,19 +582,21 @@ int main(int argc, const char * const *argv)
             throw "ե mmap ˼Ԥޤ";
         }
 
-        lexer = new TemplateLexer(pool,
-                                  reinterpret_cast<const char *>(file_map->mm),
-                                  static_cast<apr_size_t>(info.size));
-        parser = new TemplateParser(pool);
-        node = parser->parse(lexer->get_token_list(), lexer->get_ident_map());
+        TemplateLexer lexer(pool,
+                            static_cast<const char *>(file_map->mm),
+                            static_cast<apr_size_t>(info.size));
+        TemplateParser parser(pool);
+        node = parser.parse(lexer.get_token_list(), lexer.get_ident_map());
 
-        executor = new TemplateExecutor();
-        vmap = new TemplateExecutor::variable_map(lexer->get_ident_map()->size()+SYSTEM_KEY_NUMBER, NULL);
-        item_list = UploadItemList::load(pool, argv[1], TOTAL_SIZE_LIMIT);
-        ident_id = TemplateExecutor::get_ident_id(lexer->get_ident_map(), UPLOAD_ITEM_LIST_KEY);
-        vmap->at(ident_id) = item_list->to_varray(0, item_list->size());
+        TemplateExecutor executor;
+        TemplateExecutor::variable_map vmap(lexer.get_ident_map()->size()+SYSTEM_KEY_NUMBER, NULL);
 
-        executor->exec(pool, NULL, node, lexer->get_ident_map(), vmap);
+        auto_ptr<UploadItemList> item_list(UploadItemList::load(pool, argv[1], argv[1],
+                                                                TOTAL_NUMBER_LIMIT, TOTAL_SIZE_LIMIT));
+        ident_id = TemplateExecutor::get_ident_id(lexer.get_ident_map(), FILE_LIST_KEY);
+        vmap.at(ident_id) = item_list->to_varray(pool, 0, item_list->size());
+
+        executor.exec(pool, NULL, node, lexer.get_ident_map(), &vmap);
 
         if (apr_mmap_delete(file_map) != APR_SUCCESS) {
             throw "ե unmap ˼Ԥޤ";
@@ -607,12 +605,6 @@ int main(int argc, const char * const *argv)
         if (apr_file_close(fd) != APR_SUCCESS) {
             throw "ե close ˼Ԥޤ";
         }
-
-        delete item_list;
-        delete vmap;
-        delete executor;
-        delete parser;
-        delete lexer;
     } catch(const char *message) {
         cerr << "Error: " << message << endl;
         usage(argv[0]);
