@@ -24,7 +24,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: TemplateLexer.cpp 397 2005-05-17 14:54:42Z svn $
+ * $Id: TemplateLexer.cpp 452 2005-07-10 18:06:57Z svn $
  *****************************************************************************/
 
 #include "TemplateLexer.h"
@@ -139,17 +139,16 @@ TemplateLexer::token_type_str TemplateLexer::token_type_list[] = {
  * public ᥽å
  *****************************************************************************/
 TemplateLexer::TemplateLexer(apr_pool_t *pool, const char *input, apr_size_t length)
-    : pool_(pool)
+    : pool_(pool),
+      handle_(input, length),
+      token_pool_(NULL),
+      token_pool_end_(NULL),
+      is_done_(false)
 {
     if (apr_pool_create(&temp_pool_, pool) != APR_SUCCESS) {
         throw "γݤ˼Ԥޤ";
     }
 
-    token_pool_         = NULL;
-    token_pool_end_     = NULL;
-    is_done_            = false;
-
-    handle_.set_input(input, length);
     tvector_.reserve(TOKEN_POOL_NUM);
 }
 
@@ -323,7 +322,7 @@ TemplateLexer::token *TemplateLexer::get_token(handle *h,
         }
         token->type = STRING;
 
-        token->s_val = reinterpret_cast<char *>(apr_palloc(temp_pool_,
+        token->s_val = static_cast<char *>(apr_palloc(temp_pool_,
                                                       sizeof(char)*(h->input-start)));
 
         s_value = const_cast<char *>(token->s_val);
@@ -445,7 +444,7 @@ TemplateLexer::token *TemplateLexer::read_tmpl_string(handle *h)
     const char *var_end;
     token *token;
 
-    str_end = reinterpret_cast<char *>(memmem(h->input, h->input_end-h->input,
+    str_end = static_cast<char *>(memmem(h->input, h->input_end-h->input,
                                               CODE_BEGIN_STR, strlen(CODE_BEGIN_STR)));
 
     if (str_end == NULL) {
@@ -543,7 +542,7 @@ apr_size_t TemplateLexer::get_imap_id(const char * const start, apr_size_t lengt
     }
 
     if (id == imap_.size()) {
-        imap_.push_back(reinterpret_cast<const char *>(apr_pstrndup(pool_, start,
+        imap_.push_back(static_cast<const char *>(apr_pstrndup(pool_, start,
                                                                     length)));
     }
 
@@ -554,7 +553,7 @@ inline TemplateLexer::token *TemplateLexer::create_token(token_type type)
 {
     if (token_pool_ == token_pool_end_) {
         token_pool_
-            = reinterpret_cast<token *>(apr_palloc(temp_pool_,
+            = static_cast<token *>(apr_palloc(temp_pool_,
                                                    sizeof(token)*TOKEN_POOL_NUM));
         token_pool_end_ = token_pool_ + TOKEN_POOL_NUM;
     }
@@ -583,7 +582,6 @@ void usage(const char *prog_name)
 
 int main(int argc, const char * const *argv)
 {
-    TemplateLexer *lexer = NULL;
     apr_pool_t *pool;
     apr_file_t *fd;
     apr_mmap_t *file_map;
@@ -614,12 +612,12 @@ int main(int argc, const char * const *argv)
             throw "ե mmap ˼Ԥޤ";
         }
 
-        lexer = new TemplateLexer(pool,
-                                  reinterpret_cast<const char *>(file_map->mm),
-                                  static_cast<apr_size_t>(info.size));
+        TemplateLexer lexer(pool,
+                            static_cast<const char *>(file_map->mm),
+                            static_cast<apr_size_t>(info.size));
 
-        tvector = lexer->get_token_list();
-        imap = lexer->get_ident_map();
+        tvector = lexer.get_token_list();
+        imap = lexer.get_ident_map();
 
         TemplateLexer::token_vector::iterator i;
         for (i = tvector->begin(); i != tvector->end(); i++) {
@@ -633,8 +631,6 @@ int main(int argc, const char * const *argv)
         if (apr_file_close(fd) != APR_SUCCESS) {
             throw "ե close ˼Ԥޤ";
         }
-
-        delete lexer;
     } catch(const char *message) {
         cerr << "Error: " << message << endl;
         usage(argv[0]);
