@@ -24,7 +24,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: TemplateParser.cpp 423 2005-07-02 08:07:40Z svn $
+ * $Id: TemplateParser.cpp 452 2005-07-10 18:06:57Z svn $
  *****************************************************************************/
 
 #include "TemplateParser.h"
@@ -79,10 +79,11 @@ TemplateParser::node_type_str TemplateParser::node_type_list[] = {
  * public ᥽å
  *****************************************************************************/
 TemplateParser::TemplateParser(apr_pool_t *pool)
-    : pool_(pool)
+    : pool_(pool),
+      node_pool_(NULL),
+      node_pool_end_(NULL)
 {
-    node_pool_          = NULL;
-    node_pool_end_      = NULL;
+
 }
 
 TemplateParser::node *TemplateParser::parse(token_vector* tvector,
@@ -1014,7 +1015,7 @@ inline TemplateParser::node *TemplateParser::create_node(node_type type)
 {
     if (node_pool_ == node_pool_end_) {
         node_pool_
-            = reinterpret_cast<node *>(apr_pcalloc(pool_,
+            = static_cast<node *>(apr_pcalloc(pool_,
                                                   sizeof(node)*NODE_POOL_NUM));
         node_pool_end_ = node_pool_ + NODE_POOL_NUM;
     }
@@ -1077,8 +1078,6 @@ void usage(const char *prog_name)
 
 int main(int argc, const char * const *argv)
 {
-    TemplateParser *parser = NULL;
-    TemplateLexer *lexer = NULL;
     apr_pool_t *pool;
     apr_file_t *fd;
     apr_mmap_t *file_map;
@@ -1108,11 +1107,11 @@ int main(int argc, const char * const *argv)
             throw "ե mmap ˼Ԥޤ";
         }
 
-        lexer = new TemplateLexer(pool,
-                                  reinterpret_cast<const char *>(file_map->mm),
-                                  static_cast<apr_size_t>(info.size));
-        parser = new TemplateParser(pool);
-        node = parser->parse(lexer->get_token_list(), lexer->get_ident_map());
+        TemplateLexer lexer(pool,
+                            static_cast<const char *>(file_map->mm),
+                            static_cast<apr_size_t>(info.size));
+        TemplateParser parser(pool);
+        node = parser.parse(lexer.get_token_list(), lexer.get_ident_map());
         TemplateParser::print_dot(node);
 
         if (apr_mmap_delete(file_map) != APR_SUCCESS) {
@@ -1122,9 +1121,6 @@ int main(int argc, const char * const *argv)
         if (apr_file_close(fd) != APR_SUCCESS) {
             throw "ե close ˼Ԥޤ";
         }
-
-        delete parser;
-        delete lexer;
     } catch(const char *message) {
         cerr << "Error: " << message << endl;
         usage(argv[0]);
