@@ -24,7 +24,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: UploadItem.cpp 425 2005-07-03 16:20:20Z svn $
+ * $Id: UploadItem.cpp 452 2005-07-10 18:06:57Z svn $
  *****************************************************************************/
 
 #include "UploadItem.h"
@@ -139,7 +139,7 @@ const char *UploadItem::get_time()
     char *time_str;
     apr_size_t size;
 
-    time_str = reinterpret_cast<char *>(apr_palloc(pool_, sizeof(char)*MAX_TIME_LENGTH));
+    time_str = static_cast<char *>(apr_palloc(pool_, sizeof(char)*MAX_TIME_LENGTH));
 
     if (time_str == NULL) {
         throw "ɽΤΥݤ˼Ԥޤ";
