@@ -24,7 +24,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: UploadItemCreator.cpp 425 2005-07-03 16:20:20Z svn $
+ * $Id: UploadItemCreator.cpp 452 2005-07-10 18:06:57Z svn $
  *****************************************************************************/
 
 #include "UploadItemCreator.h"
@@ -35,44 +35,35 @@
  * public ᥽å
  *****************************************************************************/
 UploadItem::header *UploadItemCreator::create_header(apr_pool_t *pool,
-                                              UploadParser::query_map *qmap,
-                                              const char **tmp_path)
+                                                     UploadParser::query_map *qmap,
+                                                     const char **tmp_path)
 {
     UploadItem::header *data;
-    UploadParser::file_content *file;
 
     validate_query(qmap);
 
-    data = reinterpret_cast<UploadItem::header *>(apr_pcalloc(pool,
-                                                              sizeof(UploadItem::header)));
+    data = static_cast<UploadItem::header *>(apr_pcalloc(pool,
+                                                         sizeof(UploadItem::header)));
 
     strncpy(data->identifier, PACKAGE_NAME, sizeof(PACKAGE_NAME));
     strncpy(data->version, PACKAGE_VERSION, sizeof(PACKAGE_VERSION));
 
     data->time = apr_time_now();
     strncpy(data->comment,
-            ap_escape_html(pool, (*qmap)[UploadItem::COMMENT_PARAM]->text),
+            ap_escape_html(pool, (*qmap)[UploadItem::COMMENT_PARAM].text.c_str()),
             UploadItem::MAX_COMMENT_LENGTH);
 
     // ѥɤ ap_escape_html ʤ
-    strncpy(data->download_pass, (*qmap)[UploadItem::DOWNLOAD_PASS_PARAM]->text,
+    strncpy(data->download_pass, (*qmap)[UploadItem::DOWNLOAD_PASS_PARAM].text.c_str(),
             UploadItem::MAX_DOWNLOAD_PASS_LENGTH);
 
     // ѥɤ ap_escape_html ʤ
-    strncpy(data->remove_pass, (*qmap)[UploadItem::REMOVE_PASS_PARAM]->text,
+    strncpy(data->remove_pass, (*qmap)[UploadItem::REMOVE_PASS_PARAM].text.c_str(),
             UploadItem::MAX_REMOVE_PASS_LENGTH);
 
-    file = (*qmap)[UploadItem::FILE_PARAM]->file;
-    data->file_size = file->size;
-    strncpy(data->file_mime, ap_escape_html(pool, file->mime),
-            UploadItem::MAX_FILE_MIME_LENGTH);
+    set_file_data(pool, data, (*qmap)[UploadItem::FILE_PARAM].file, qmap);
 
-    strncpy(data->file_name,
-            ap_escape_html(pool, CharCodeConverter::convert(pool, file->name,
-                                                            (*qmap)[UploadItem::CODE_PAT_PARAM]->text)),
-            UploadItem::MAX_FILE_NAME_LENGTH);
-
-    *tmp_path = file->tmp_path;
+    *tmp_path = (*qmap)[UploadItem::FILE_PARAM].file.tmp_path.c_str();
 
     return data;
 }
@@ -89,14 +80,14 @@ void UploadItemCreator::validate_query(UploadParser::query_map *qmap)
 
     if (qmap->count(UploadItem::FILE_PARAM) != 1) {
         throw "եλ꤬Ǥ";
-    } else if (((*qmap)[UploadItem::FILE_PARAM]->type != UploadParser::FILE) ||
-               ((*qmap)[UploadItem::FILE_PARAM]->file->size == 0)) {
+    } else if (((*qmap)[UploadItem::FILE_PARAM].type != UploadParser::FILE) ||
+               ((*qmap)[UploadItem::FILE_PARAM].file.size == 0)) {
         throw "ե뤬Ǥ";
-    } else if (strlen((*qmap)[UploadItem::FILE_PARAM]->file->mime) >= UploadItem::MAX_FILE_MIME_LENGTH) {
+    } else if ((*qmap)[UploadItem::FILE_PARAM].file.mime.length() >= UploadItem::MAX_FILE_MIME_LENGTH) {
         throw "ե MIME Type Ĺޤ";
     }
     {
-        const char *file_name = (*qmap)[UploadItem::FILE_PARAM]->file->name;
+        const char *file_name = (*qmap)[UploadItem::FILE_PARAM].file.name.c_str();
 
         if (strlen(file_name) >= UploadItem::MAX_FILE_NAME_LENGTH) {
             throw "ե̾Ĺޤ";
@@ -112,22 +103,22 @@ void UploadItemCreator::validate_query(UploadParser::query_map *qmap)
 
     if (qmap->count(UploadItem::COMMENT_PARAM) != 1) {
         throw "Ȥλ꤬Ǥ";
-    } else if (((*qmap)[UploadItem::COMMENT_PARAM]->type != UploadParser::TEXT) ||
-               (strlen((*qmap)[UploadItem::COMMENT_PARAM]->text) >= UploadItem::MAX_COMMENT_LENGTH)) {
+    } else if (((*qmap)[UploadItem::COMMENT_PARAM].type != UploadParser::TEXT) ||
+               ((*qmap)[UploadItem::COMMENT_PARAM].text.length() >= UploadItem::MAX_COMMENT_LENGTH)) {
         throw "ȤĹޤ";
     }
 
     if (qmap->count(UploadItem::DOWNLOAD_PASS_PARAM) != 1) {
         throw "ɥѥɤλ꤬Ǥ";
-    } else if (((*qmap)[UploadItem::DOWNLOAD_PASS_PARAM]->type != UploadParser::TEXT) ||
-               (strlen((*qmap)[UploadItem::DOWNLOAD_PASS_PARAM]->text) >= UploadItem::MAX_DOWNLOAD_PASS_LENGTH)) {
+    } else if (((*qmap)[UploadItem::DOWNLOAD_PASS_PARAM].type != UploadParser::TEXT) ||
+               ((*qmap)[UploadItem::DOWNLOAD_PASS_PARAM].text.length() >= UploadItem::MAX_DOWNLOAD_PASS_LENGTH)) {
         throw "ɥѥɤĹޤ";
     }
 
     if (qmap->count(UploadItem::REMOVE_PASS_PARAM) != 1) {
         throw "ѥɤλ꤬Ǥ";
-    } else if (((*qmap)[UploadItem::REMOVE_PASS_PARAM]->type != UploadParser::TEXT) ||
-               (strlen((*qmap)[UploadItem::REMOVE_PASS_PARAM]->text) >= UploadItem::MAX_REMOVE_PASS_LENGTH)) {
+    } else if (((*qmap)[UploadItem::REMOVE_PASS_PARAM].type != UploadParser::TEXT) ||
+               ((*qmap)[UploadItem::REMOVE_PASS_PARAM].text.length() >= UploadItem::MAX_REMOVE_PASS_LENGTH)) {
         throw "ѥɤĹޤ";
     }
 
@@ -136,6 +127,23 @@ void UploadItemCreator::validate_query(UploadParser::query_map *qmap)
     }
 }
 
+void UploadItemCreator::set_file_data(apr_pool_t *pool,
+                                      UploadItem::header *data,
+                                      UploadParser::file_content& file,
+                                      UploadParser::query_map *qmap)
+{
+    data->file_size = file.size;
+
+    strncpy(data->file_mime, ap_escape_html(pool, file.mime.c_str()),
+            UploadItem::MAX_FILE_MIME_LENGTH);
+
+    strncpy(data->file_name,
+            ap_escape_html(pool,
+                           CharCodeConverter::convert(pool, file.name.c_str(),
+                                                      (*qmap)[UploadItem::CODE_PAT_PARAM].text.c_str())),
+            UploadItem::MAX_FILE_NAME_LENGTH);
+}
+
 // Local Variables:
 // mode: c++
 // buffer-file-coding-system: euc-japan-dos
