@@ -24,7 +24,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: UploadItemList.cpp 425 2005-07-03 16:20:20Z svn $
+ * $Id: UploadItemList.cpp 454 2005-07-13 20:57:51Z svn $
  *****************************************************************************/
 
 #include "UploadItemList.h"
@@ -54,15 +54,11 @@ UploadItemList::UploadItemList(apr_pool_t *pool,
       file_dir_(file_dir),
       thumb_dir_(thumb_dir),
       total_number_limit_(total_number_limit),
-      total_size_limit_(total_size_limit)
+      total_size_limit_(total_size_limit),
+      reader(pool, file_dir),
+      total_size_(0)
 {
-    total_size_ = 0;
-    reader      = new UploadItemReader(pool_, file_dir_);
-}
 
-UploadItemList::~UploadItemList()
-{
-    delete reader;
 }
 
 void UploadItemList::add(const char *file_path, bool is_make_thumb)
@@ -71,12 +67,12 @@ void UploadItemList::add(const char *file_path, bool is_make_thumb)
     item_info *info;
     apr_file_t *file;
 
-    header = reader->read(file_path, &file);
+    header = reader.read(file_path, &file);
     apr_file_close(file);
 
-    info = reinterpret_cast<item_info *>(apr_palloc(pool_,
+    info = static_cast<item_info *>(apr_palloc(pool_,
                                                     sizeof(item_info)));
-    info->file_path = reinterpret_cast<const char *>(apr_pstrdup(pool_, file_path));
+    info->file_path = static_cast<const char *>(apr_pstrdup(pool_, file_path));
     info->header = header;
 
     ilist_.push_front(info);
@@ -163,7 +159,7 @@ TemplateExecutor::variable *UploadItemList::to_varray(apr_pool_t *pool,
     for (apr_size_t j = 0; (j < size) && (i != end()); j++, i++) {
         item.set_data((*i)->file_path, (*i)->header);
 
-        var = reinterpret_cast<TemplateExecutor::variable **>(apr_array_push(array));
+        var = static_cast<TemplateExecutor::variable **>(apr_array_push(array));
         *var = TemplateVariableCreator::create(pool, &item);
     }
 
@@ -185,7 +181,7 @@ TemplateExecutor::variable *UploadItemList::to_thumb_varray(apr_pool_t *pool,
     }
 
     for (apr_size_t j = 0; (j < size) && (i != tlist_.end()); j++, i++) {
-         var = reinterpret_cast<TemplateExecutor::variable **>(apr_array_push(array));
+         var = static_cast<TemplateExecutor::variable **>(apr_array_push(array));
          *var = TemplateVariableCreator::create(pool, (*i).c_str());
     }
 
@@ -204,7 +200,7 @@ UploadItemList::item_info **UploadItemList::to_array(apr_pool_t *pool,
         i++;
     }
 
-    item_list = reinterpret_cast<item_info **>(apr_pcalloc(pool,
+    item_list = static_cast<item_info **>(apr_pcalloc(pool,
                                                            sizeof(item_info *)*(size+1)));
     item = item_list;
     for (apr_size_t j = 0; (j < size) && (i != end()); j++, i++) {
@@ -301,12 +297,12 @@ void UploadItemList::init()
 
     apr_dir_close(dir);
 
-    if (tlist_.size() > 0) {
-        tlist_.sort();
+    if (!tlist_.empty()) {
+        tlist_.sort(ThumbnailCompare());
     }
 #endif
 
-    if (ilist_.size() > 0) {
+    if (!ilist_.empty()) {
         ilist_.sort(ItemCompare());
     }
     mtime_ = apr_time_now();
@@ -353,6 +349,7 @@ void UploadItemList::remove(item_info *info)
 #ifdef DEBUG_UploadItemList
 #include "apr_general.h"
 
+const apr_size_t TOTAL_NUMBER_LIMIT = 100;
 const apr_size_t TOTAL_SIZE_LIMIT   = 1024*1024*1024;
 
 void usage(const char *prog_name)
@@ -362,7 +359,6 @@ void usage(const char *prog_name)
 
 int main(int argc, const char * const *argv)
 {
-    UploadItemList *item_list = NULL;
     apr_pool_t *pool;
 
     apr_app_initialize(&argc, &argv, NULL);
@@ -373,11 +369,11 @@ int main(int argc, const char * const *argv)
             throw "եѥǥ쥯ȥ꤬ꤵƤޤ";
         }
 
-        item_list = UploadItemList::load(pool, argv[1], TOTAL_SIZE_LIMIT);
-        UploadItemList::dump_list(item_list);
-        item_list->to_array(0, item_list->size());
+        auto_ptr<UploadItemList> item_list(UploadItemList::load(pool, argv[1], argv[1],
+                                                                TOTAL_NUMBER_LIMIT, TOTAL_SIZE_LIMIT));
 
-        delete item_list;
+        UploadItemList::dump_list(item_list.get());
+        item_list->to_array(pool, 0, item_list->size());
     } catch(const char *message) {
         cerr << "Error: " << message << endl;
         usage(argv[0]);
