@@ -24,7 +24,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: UploadItemReader.cpp 374 2005-05-14 06:44:51Z svn $
+ * $Id: UploadItemReader.cpp 452 2005-07-10 18:06:57Z svn $
  *****************************************************************************/
 
 #include "UploadItemReader.h"
@@ -73,7 +73,7 @@ UploadItem::header *UploadItemReader::read(const char *file_name,
         throw "åץɥե򳫤ޤǤ";
     }
 
-    header = reinterpret_cast<UploadItem::header *>(apr_pcalloc(pool, sizeof(UploadItem::header)));
+    header = static_cast<UploadItem::header *>(apr_pcalloc(pool, sizeof(UploadItem::header)));
     size = sizeof(UploadItem::header);
     if ((apr_file_read(*file, header, &size) != APR_SUCCESS) ||
         (size != sizeof(UploadItem::header))) {
@@ -103,12 +103,19 @@ UploadItem::header *UploadItemReader::read(const char *file_name,
 
 #include "RFC1867ParserImpl.h"
 #include "UploadItem.h"
+#include "UploadItemCreator.h"
 #include "UploadItemWriter.h"
 
 static const apr_size_t  BUFSIZE        = 256;
 static const char FILE_DIR[]            = "/tmp";
 static const char CONTENT_TYPE_TMPL[]   = "multipart/form-data; boundary=%s";
 
+// ߡ
+char *ap_escape_html(apr_pool_t *pool, const char *str)
+{
+    return const_cast<char *>(str);
+}
+
 void usage(const char *prog_name)
 {
     cerr << "Usage: " << prog_name << " <INPUT>" << endl;
@@ -120,11 +127,7 @@ int main(int argc, const char * const *argv)
     apr_pool_t *pool;
     apr_file_t *fd;
     apr_off_t offset;
-    UploadParser *parser;
-    UploadParser::query_map *qmap;
     UploadItem::header *header;
-    UploadItemWriter *writer;
-    UploadItemReader *reader;
     const char *tmp_path;
     const char *file_path;
 
@@ -149,26 +152,23 @@ int main(int argc, const char * const *argv)
             throw "ѤΥե seek ˼Ԥޤ";
         }
 
-        parser = new UploadParser(FILE_DIR, 10*1024*1024, 32*1024*1024, 5,
-                                  UploadItem::ITEM_HEADER_SIZE);
-        qmap = parser->parse(pool, fd,
-                             apr_psprintf(pool, CONTENT_TYPE_TMPL, content_type+2));
+        UploadParser parser (FILE_DIR, 10*1024*1024, 32*1024*1024, 5,
+                             UploadItem::ITEM_HEADER_SIZE);
 
-        writer = new UploadItemWriter(pool, FILE_DIR);
-        header = UploadItem::create_header(pool, qmap, &tmp_path);
-        file_path = writer->write(header, tmp_path);
+        auto_ptr<UploadParser::query_map>
+            qmap(parser.parse(pool, fd,
+                              apr_psprintf(pool, CONTENT_TYPE_TMPL, content_type+2)));
 
-        reader = new UploadItemReader(pool, FILE_DIR);
-        header = reader->read(basename_ex(file_path), &fd);
+        UploadItemWriter writer(pool, FILE_DIR);
+        header = UploadItemCreator::create_header(pool, qmap.get(), &tmp_path);
 
-        UploadParser::clean_tmp_file(pool, qmap);
+        file_path = writer.write(header, tmp_path);
+
+        UploadItemReader reader(pool, FILE_DIR);
+        header = reader.read(basename_ex(file_path), &fd);
+
+        UploadParser::clean_tmp_file(pool, qmap.get());
         UploadItem::dump_header(header);
-        UploadParser::clear_map(qmap);
-
-        delete reader;
-        delete writer;
-        delete qmap;
-        delete parser;
     } catch(const char *message) {
         cerr << "Error: " << message << endl;
         usage(argv[0]);
