@@ -24,7 +24,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: UploaderConfig.cpp 426 2005-07-03 19:24:03Z svn $
+ * $Id: UploaderConfig.cpp 452 2005-07-10 18:06:57Z svn $
  *****************************************************************************/
 
 #include "UploaderConfig.h"
@@ -48,7 +48,6 @@
 #define DELETE(ptr) if (ptr != NULL) { delete ptr; ptr = NULL;}
 #define CLEAR(pool) if (pool != NULL) { apr_pool_clear(pool); pool = NULL;}
 
-// const char UploaderConfig::MUTEX_TEMPLATE[]             = "mutex.XXXXXX";
 const apr_uint64_t UploaderConfig::TOTAL_FILE_SIZE_LIMIT= 10*1024*1024;
 const apr_size_t UploaderConfig::TOTAL_FILE_NUMBER_LIMIT= 1000;
 const apr_size_t UploaderConfig::MAX_FORM_FILE_SIZE     = 1*1024*1024;
@@ -59,49 +58,45 @@ const apr_size_t UploaderConfig::ITEM_RELOAD_THRESHOLD  = 100;
 
 static apr_status_t finalize_config(void *data);
 #if APR_HAS_THREADS
-static apr_status_t finalize_mutex(void *data);
+static apr_status_t finalize_rwlock(void *data);
 #endif
 
 /******************************************************************************
  * public ᥽å
  *****************************************************************************/
 UploaderConfig::UploaderConfig()
-{
-    url                     = "";
-    file_dir                = NULL;
-    tmp_dir                 = NULL;
-    lock_dir                = NULL;
-    view_tmpl_path          = NULL;
-    download_tmpl_path      = NULL;
-    thumb_tmpl_path         = NULL;
-    error_tmpl_path         = NULL;
-    max_file_size           = MAX_FORM_FILE_SIZE;
-    total_file_size_limit   = TOTAL_FILE_SIZE_LIMIT;
-    total_file_number_limit = TOTAL_FILE_NUMBER_LIMIT;
-    per_page_item_number    = PER_PAGE_ITEM_NUMBER;
-
-    item_list               = NULL;
-    list_pool               = NULL;
-
-    view_tmpl               = NULL;
-    view_tmpl_pool          = NULL;
-    download_tmpl           = NULL;
-    download_tmpl_pool      = NULL;
-    thumb_tmpl              = NULL;
-    thumb_tmpl_pool         = NULL;
-    error_tmpl              = NULL;
-    error_tmpl_pool         = NULL;
-
-    texecutor               = NULL;
-    uparser                 = NULL;
-
+    : url(""),
+      file_dir(NULL),
+      thumb_dir(NULL),
+      tmp_dir(NULL),
+      lock_dir(NULL),
+      view_tmpl_path(NULL),
+      download_tmpl_path(NULL),
+      thumb_tmpl_path(NULL),
+      error_tmpl_path(NULL),
+      total_file_size_limit( TOTAL_FILE_SIZE_LIMIT),
+      total_file_number_limit( TOTAL_FILE_NUMBER_LIMIT),
+      max_file_size(MAX_FORM_FILE_SIZE),
+      per_page_item_number( PER_PAGE_ITEM_NUMBER),
+      remove_item_number(0),
+      item_list(NULL),
+      texecutor(NULL),
+      uparser(NULL),
+      view_tmpl(NULL),
+      view_tmpl_pool(NULL),
+      download_tmpl(NULL),
+      download_tmpl_pool(NULL),
+      thumb_tmpl(NULL),
+      thumb_tmpl_pool(NULL),
+      error_tmpl(NULL),
+      error_tmpl_pool(NULL),
+      list_pool(NULL),
 #if APR_HAS_THREADS
-    mutex                   = NULL;
+      rwlock(NULL),
 #endif
+      is_init(false)
+{
 
-    remove_item_nmber       = 0;
-
-    is_init                 = false;
 }
 
 UploaderConfig::~UploaderConfig()
@@ -118,7 +113,7 @@ void UploaderConfig::init(apr_pool_t *pool, apr_pool_t *tmp_pool)
     validate();
 
 #if APR_HAS_THREADS
-    init_mutex(pool, tmp_pool);
+    init_rwlock(pool, tmp_pool);
 #endif
     load_list(pool);
 
@@ -141,6 +136,7 @@ void UploaderConfig::init(apr_pool_t *pool, apr_pool_t *tmp_pool)
 
 void UploaderConfig::finalize()
 {
+    // Ӥߤ硼
     DELETE(uparser);
     DELETE(texecutor);
     DELETE(item_list);
@@ -206,10 +202,19 @@ UploadItemWriter *UploaderConfig::get_uwriter(apr_pool_t *pool)
     return new UploadItemWriter(pool, file_dir);
 }
 
-apr_status_t UploaderConfig::lock()
+apr_status_t UploaderConfig::read_lock()
 {
 #if APR_HAS_THREADS
-    return apr_thread_mutex_lock(mutex);
+    return apr_thread_rwlock_rdlock(rwlock);
+#else
+    return APR_SUCCESS;
+#endif
+}
+
+apr_status_t UploaderConfig::write_lock()
+{
+#if APR_HAS_THREADS
+    return apr_thread_rwlock_wrlock(rwlock);
 #else
     return APR_SUCCESS;
 #endif
@@ -218,7 +223,7 @@ apr_status_t UploaderConfig::lock()
 apr_status_t UploaderConfig::unlock()
 {
 #if APR_HAS_THREADS
-    return apr_thread_mutex_unlock(mutex);
+    return apr_thread_rwlock_unlock(rwlock);
 #else
     return APR_SUCCESS;
 #endif
@@ -243,9 +248,13 @@ void UploaderConfig::validate()
 }
 
 #if APR_HAS_THREADS
-void UploaderConfig::init_mutex(apr_pool_t *pool, apr_pool_t *tmp_pool)
+void UploaderConfig::init_rwlock(apr_pool_t *pool, apr_pool_t *tmp_pool)
 {
-    mutex = create_mutex(pool, tmp_pool, lock_dir);
+    if (apr_thread_rwlock_create(&rwlock, pool) != APR_SUCCESS) {
+        throw "åǤޤǤ";
+    }
+
+    apr_pool_cleanup_register(pool, rwlock, apr_pool_cleanup_null, finalize_rwlock);
 }
 #endif
 
@@ -264,10 +273,10 @@ void UploaderConfig::load_list(apr_pool_t *pool)
 
 void UploaderConfig::update_list(apr_pool_t *pool, apr_pool_t *tmp_pool)
 {
-    try {
-        // äȴɡΨͤƤΰ֤ǥå(äѤᡩ)
-        lock();
-        if (get_mtime(tmp_pool, file_dir) > item_list->get_mtime()) {
+    if (get_mtime(tmp_pool, file_dir) > item_list->get_mtime()) {
+        try {
+            // äȴɡΨͤƤΰ֤ǥå(äѤᡩ)
+            write_lock();
 
             load_list(pool);
 
@@ -293,16 +302,24 @@ void UploaderConfig::update_list(apr_pool_t *pool, apr_pool_t *tmp_pool)
             time.modtime = time.actime = mtime/1000000;
             utime(file_dir, &time);
 #endif
-        } else if (remove_item_nmber++ == ITEM_RELOAD_THRESHOLD) {
-            load_list(pool);
-            remove_item_nmber = 0;
+            unlock();
+        } catch(const char *) {
+            unlock();
+            throw;
         }
-        unlock();
+    } else if (remove_item_number++ == ITEM_RELOAD_THRESHOLD) {
+        try {
+            // äȴɡΨͤƤΰ֤ǥå(äѤᡩ)
+            write_lock();
 
-        return;
-    } catch(const char *) {
-        unlock();
-        throw;
+            load_list(pool);
+            remove_item_number = 0;
+
+            unlock();
+        } catch(const char *) {
+            unlock();
+            throw;
+        }
     }
 }
 
@@ -335,7 +352,7 @@ void UploaderConfig::load_template(apr_pool_t *pool, apr_pool_t **tmpl_pool,
             throw "ƥץ졼ѤΥݤ˼Ԥޤ";
         }
 
-        TemplateLexer lexer(*tmpl_pool, reinterpret_cast<const char *>(file_map->mm),
+        TemplateLexer lexer(*tmpl_pool, static_cast<const char *>(file_map->mm),
                             static_cast<apr_size_t>(info.size));
         TemplateParser parser(*tmpl_pool);
 
@@ -367,37 +384,6 @@ apr_time_t UploaderConfig::get_mtime(apr_pool_t *pool, const char *file_path)
     return info.mtime;
 }
 
-#if APR_HAS_THREADS
-apr_thread_mutex_t *UploaderConfig::create_mutex(apr_pool_t *pool, apr_pool_t *tmp_pool,
-                                                 const char *lock_dir)
-{
-    apr_thread_mutex_t *mutex;
-//     char *lock_name;
-//     apr_file_t *file;
-
-//     if (apr_filepath_merge(&lock_name, lock_dir, name,
-//                            APR_FILEPATH_NOTABOVEROOT, tmp_pool) != APR_SUCCESS) {
-//         throw "mutex ̾ǤޤǤ(1)";
-//     }
-
-//     // Ӥߤ硼
-//     if (apr_file_mktemp(&file, lock_name,
-//                         APR_CREATE|APR_WRITE|APR_EXCL|APR_DELONCLOSE,
-//                         pool) != APR_SUCCESS) {
-//         throw "mutex ̾ǤޤǤ(2)";
-//     }
-//     apr_file_close(file);
-
-    if (apr_thread_mutex_create(&mutex, APR_THREAD_MUTEX_DEFAULT, pool) != APR_SUCCESS) {
-        throw "mutex ǤޤǤ";
-    }
-
-    apr_pool_cleanup_register(pool, mutex, apr_pool_cleanup_null, finalize_mutex);
-
-    return mutex;
-}
-#endif
-
 
 /******************************************************************************
  * Хåؿ
@@ -406,19 +392,19 @@ apr_status_t finalize_config(void *data)
 {
     UploaderConfig *config;
 
-    config = reinterpret_cast<UploaderConfig *>(data);
+    config = static_cast<UploaderConfig *>(data);
     config->finalize();
 
     return APR_SUCCESS;
 }
 
 #if APR_HAS_THREADS
-apr_status_t finalize_mutex(void *data)
+apr_status_t finalize_rwlock(void *data)
 {
-    apr_thread_mutex_t *mutex;
+    apr_thread_rwlock_t *rwlock;
 
-    mutex = reinterpret_cast<apr_thread_mutex_t *>(data);
-    apr_thread_mutex_destroy(mutex);
+    rwlock = static_cast<apr_thread_rwlock_t *>(data);
+    apr_thread_rwlock_destroy(rwlock);
 
     return APR_SUCCESS;
 }
