@@ -1,4 +1,4 @@
- /******************************************************************************
+/******************************************************************************
  * mod_uploader / mod_uploader.cpp
  ******************************************************************************
  * Copyright (C) 2005 Tetsuya Kimata <kimata@acapulco.dyndns.org>
@@ -24,7 +24,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: mod_uploader.cpp 431 2005-07-05 03:36:31Z svn $
+ * $Id: mod_uploader.cpp 454 2005-07-13 20:57:51Z svn $
  *****************************************************************************/
 
 #include "mod_uploader.h"
@@ -43,6 +43,8 @@
 #include <stdlib.h>
 #include <string.h>
 
+#include <memory>
+
 #define MATCH(str, pat) (strstr(str, pat) != 0)
 
 #ifdef WIN32
@@ -83,7 +85,6 @@ static variable_map *get_thumb_vmap(apr_pool_t *pool, UploaderConfig *config,
                                     page_template *tmpl, apr_size_t page);
 #endif
 static apr_size_t get_page(request_rec *r);
-// static bool is_accept_gzip(request_rec *r);
 static const char *get_name_encoding(request_rec *r);
 
 int command_handler(request_rec *r, uconfig *config, const char *arg)
@@ -118,10 +119,9 @@ int command_handler(request_rec *r, uconfig *config, const char *arg)
 
 int view(request_rec *r, uconfig *config, const char *arg)
 {
-    variable_map *vmap = NULL;
     apr_status_t status;
 
-    config->lock();
+    config->read_lock();
 
     ap_update_mtime(r, config->item_list->get_mtime());
     ap_set_last_modified(r);
@@ -141,9 +141,9 @@ int view(request_rec *r, uconfig *config, const char *arg)
     try {
         page_template *tmpl = config->get_view_template(r->server->process->pool);
 
-        vmap = get_view_vmap(r->pool, config, tmpl, get_page(r));
+        auto_ptr<variable_map> vmap(get_view_vmap(r->pool, config, tmpl, get_page(r)));
 
-        config->texecutor->exec(r->pool, r, tmpl->node, tmpl->imap, vmap);
+        config->texecutor->exec(r->pool, r, tmpl->node, tmpl->imap, vmap.get());
 
         config->unlock();
 
@@ -151,10 +151,6 @@ int view(request_rec *r, uconfig *config, const char *arg)
     } catch(const char *message) {
         config->unlock();
 
-        if (vmap != NULL) {
-            delete vmap;
-        }
-
         ap_rputs("<div class=\"warning\">", r);
         ap_rputs(message, r);
         ap_rputs("</div>", r);
@@ -166,10 +162,9 @@ int view(request_rec *r, uconfig *config, const char *arg)
 #ifdef MAKE_THUMBNAIL
 int thumbnail(request_rec *r, uconfig *config, const char *arg)
 {
-    variable_map *vmap = NULL;
     apr_status_t status;
 
-    config->lock();
+    config->read_lock();
 
     ap_update_mtime(r, config->item_list->get_mtime());
     ap_set_last_modified(r);
@@ -189,9 +184,9 @@ int thumbnail(request_rec *r, uconfig *config, const char *arg)
     try {
         page_template *tmpl = config->get_thumb_template(r->server->process->pool);
 
-        vmap = get_thumb_vmap(r->pool, config, tmpl, get_page(r));
+        auto_ptr<variable_map> vmap(get_thumb_vmap(r->pool, config, tmpl, get_page(r)));
 
-        config->texecutor->exec(r->pool, r, tmpl->node, tmpl->imap, vmap);
+        config->texecutor->exec(r->pool, r, tmpl->node, tmpl->imap, vmap.get());
 
         config->unlock();
 
@@ -199,10 +194,6 @@ int thumbnail(request_rec *r, uconfig *config, const char *arg)
     } catch(const char *message) {
         config->unlock();
 
-        if (vmap != NULL) {
-            delete vmap;
-        }
-
         ap_rputs("<div class=\"warning\">", r);
         ap_rputs(message, r);
         ap_rputs("</div>", r);
@@ -216,7 +207,7 @@ int rss(request_rec *r, uconfig *config, const char *arg)
 {
     apr_status_t status;
 
-    config->lock();
+    config->read_lock();
 
     ap_update_mtime(r, config->item_list->get_mtime());
     ap_set_last_modified(r);
@@ -256,8 +247,6 @@ int rss(request_rec *r, uconfig *config, const char *arg)
 int upload(request_rec *r, uconfig *config, const char *arg)
 {
     apr_status_t status;
-    UploadParser::query_map *qmap = NULL;
-    UploadItemWriter *writer = NULL;
 
     if (r->method_number != M_POST) {
         return HTTP_BAD_REQUEST;
@@ -269,19 +258,28 @@ int upload(request_rec *r, uconfig *config, const char *arg)
         return HTTP_NO_CONTENT;
     }
 
+    // 㳰Ȥ
     try {
         UploadItem::header *header;
         const char *tmp_path;
         const char *file_name;
 
-        qmap = config->uparser->parse(r->pool, r, apr_table_get(r->headers_in, "Content-Type"));
-        header = UploadItemCreator::create_header(r->pool, qmap, &tmp_path);
+        auto_ptr<UploadParser::query_map>
+            qmap(config->uparser->parse(r->pool, r, apr_table_get(r->headers_in, "Content-Type")));
 
-        writer = config->get_uwriter(r->pool);
+        try {
+            header = UploadItemCreator::create_header(r->pool, qmap.get(), &tmp_path);
+        } catch(const char *) {
+            UploadParser::clean_tmp_file(r->pool, qmap.get());
+
+            throw;
+        }
+
+        auto_ptr<UploadItemWriter> writer(config->get_uwriter(r->pool));
         file_name = writer->write(header, tmp_path);
 
         try {
-            config->lock();
+            config->write_lock();
             config->item_list->add(file_name, true);
             config->unlock();
         } catch(const char *) {
@@ -289,21 +287,8 @@ int upload(request_rec *r, uconfig *config, const char *arg)
             throw;
         }
 
-        UploadParser::clear_map(qmap);
-
-        delete qmap;
-        delete writer;
-
         return redirect_top(r);
     } catch(const char *message) {
-        if (qmap != NULL) {
-            UploadParser::clear_map(qmap);
-            delete qmap;
-        }
-        if (writer != NULL) {
-            delete writer;
-        }
-
         return error(r, config, message);
     }
 }
@@ -311,7 +296,6 @@ int upload(request_rec *r, uconfig *config, const char *arg)
 int download(request_rec *r, uconfig *config, const char *arg)
 {
     const char *name;
-    UploadItemReader *reader = NULL;
 
     name = ap_getword(r->pool, &arg, '/');
     if (name == NULL) {
@@ -341,7 +325,7 @@ int download(request_rec *r, uconfig *config, const char *arg)
         apr_size_t size;
         apr_status_t status;
 
-        reader = config->get_ureader(r->pool);
+        auto_ptr<UploadItemReader> reader(config->get_ureader(r->pool));
         header = reader->read(name, &file);
 
         password = apr_table_get(get_command_table(r), UploadItem::DOWNLOAD_PASS_PARAM);
@@ -350,11 +334,7 @@ int download(request_rec *r, uconfig *config, const char *arg)
         if ((strlen(header->download_pass) > 0) &&
             ((password == NULL) ||
              (strncmp(header->download_pass, password, strlen(header->download_pass)) != 0))) {
-            int result = input_download_pass(r, config, arg, header);
-
-            delete reader;
-
-            return result;
+            return input_download_pass(r, config, arg, header);
         }
 
         ap_update_mtime(r, header->time);
@@ -386,14 +366,8 @@ int download(request_rec *r, uconfig *config, const char *arg)
 
         ap_send_fd(file, r, UploadItem::ITEM_HEADER_SIZE, header->file_size, &size);
 
-        delete reader;
-
         return OK;
     } catch(const char *message) {
-        if (reader != NULL) {
-            delete reader;
-        }
-
         return error(r, config, message);
     }
 }
@@ -401,24 +375,16 @@ int download(request_rec *r, uconfig *config, const char *arg)
 int input_download_pass(request_rec *r, uconfig *config, const char *arg,
                         UploadItem::header *header)
 {
-    variable_map *vmap = NULL;
-
     try {
         page_template *tmpl = config->get_download_template(r->server->process->pool);
 
-        vmap = get_download_vmap(r->pool, config, tmpl, header);
+        auto_ptr<variable_map> vmap(get_download_vmap(r->pool, config, tmpl, header));
 
         ap_set_content_type(r, "text/html");
-        config->texecutor->exec(r->pool, r, tmpl->node, tmpl->imap, vmap);
-
-        delete vmap;
+        config->texecutor->exec(r->pool, r, tmpl->node, tmpl->imap, vmap.get());
 
         return OK;
     } catch(const char *message) {
-        if (vmap != NULL) {
-            delete vmap;
-        }
-
         ap_rputs("<div class=\"warning\">", r);
         ap_rputs(message, r);
         ap_rputs("</div>", r);
@@ -449,10 +415,10 @@ int remove(request_rec *r, uconfig *config, const char *arg)
         }
 
         try {
-            config->lock();
+            config->write_lock();
 
             config->item_list->remove(file, password);
-            config->remove_item_nmber++;
+            config->remove_item_number++;
 
             config->unlock();
         } catch(const char *) {
@@ -509,7 +475,7 @@ int redirect_top(request_rec *r)
 
 uconfig *get_config(request_rec *r)
 {
-    return reinterpret_cast<uconfig *>(ap_get_module_config(r->per_dir_config,
+    return static_cast<uconfig *>(ap_get_module_config(r->per_dir_config,
                                                             &uploader_module));
 }
 
@@ -520,7 +486,7 @@ apr_table_t *get_command_table(request_rec *r)
     apr_table_t *table;
 
     table = apr_table_make(r->pool, MAX_COMMAND_NUMBER);
-    command = reinterpret_cast<char *>(apr_pcalloc(r->pool, MAX_COMMAND_LENGTH));
+    command = static_cast<char *>(apr_pcalloc(r->pool, MAX_COMMAND_LENGTH));
 
     if ((ap_setup_client_block(r, REQUEST_CHUNKED_ERROR) != OK) ||
         !ap_should_client_block(r)) {
@@ -545,10 +511,10 @@ apr_table_t *get_command_table(request_rec *r)
 
 variable *create_variable(apr_pool_t *pool, const char *str)
 {
-    variable *var = reinterpret_cast<variable *>(apr_palloc(pool,
+    variable *var = static_cast<variable *>(apr_palloc(pool,
                                                             sizeof(variable)));
     var->type = TemplateExecutor::SCALAR;
-    var->s_val = reinterpret_cast<scalar *>(apr_palloc(pool, sizeof(scalar)));
+    var->s_val = static_cast<scalar *>(apr_palloc(pool, sizeof(scalar)));
     var->s_val->type = TemplateExecutor::STRING;
     var->s_val->s_val = str;
 
@@ -557,10 +523,10 @@ variable *create_variable(apr_pool_t *pool, const char *str)
 
 variable *create_variable(apr_pool_t *pool, int i)
 {
-    variable *var = reinterpret_cast<variable *>(apr_palloc(pool,
+    variable *var = static_cast<variable *>(apr_palloc(pool,
                                                             sizeof(variable)));
     var->type = TemplateExecutor::SCALAR;
-    var->s_val = reinterpret_cast<scalar *>(apr_palloc(pool, sizeof(scalar)));
+    var->s_val = static_cast<scalar *>(apr_palloc(pool, sizeof(scalar)));
     var->s_val->type = TemplateExecutor::INTEGER;
     var->s_val->i_val = i;
 
@@ -676,15 +642,6 @@ apr_size_t get_page(request_rec *r)
     return static_cast<apr_size_t>(page);
 }
 
-// bool is_accept_gzip(request_rec *r)
-// {
-//     const char *accept_enc;
-
-//     accept_enc = apr_table_get(r->headers_in, ACCEPT_ENCODING);
-
-//     return strstr(accept_enc, GZIP) != NULL;
-// }
-
 const char *get_name_encoding(request_rec *r)
 {
     const char *agent = apr_table_get(r->headers_in, "User-Agent");
@@ -711,6 +668,7 @@ static int uploader_handler(request_rec *r)
     config = get_config(r);
 
     try {
+        // 
         config->init(r->server->process->pool, r->pool);
     } catch(const char *message) {
         ap_rputs("<div class=\"warning\">", r);
@@ -729,7 +687,7 @@ static apr_status_t finalize_dir_config(void *data)
 {
     uconfig *config;
 
-    config = reinterpret_cast<uconfig *>(data);
+    config = static_cast<uconfig *>(data);
     config->finalize();
 
     return APR_SUCCESS;
@@ -739,12 +697,12 @@ static void *create_dir_config(apr_pool_t *p, char *dirspec)
 {
     uconfig *config;
 
-    config = reinterpret_cast<uconfig *>(apr_pcalloc(p, sizeof(uconfig)));
+    config = static_cast<uconfig *>(apr_pcalloc(p, sizeof(uconfig)));
     new(config) uconfig;
 
     apr_pool_cleanup_register(p, config, finalize_dir_config, apr_pool_cleanup_null);
 
-    return reinterpret_cast<uconfig *>(config);
+    return static_cast<uconfig *>(config);
 }
 
 static int post_config(apr_pool_t *pconf, apr_pool_t *plog,
@@ -757,7 +715,7 @@ static int post_config(apr_pool_t *pconf, apr_pool_t *plog,
 
 static const char *set_url(cmd_parms *parms, void *mconfig, char *arg)
 {
-    uconfig *config = reinterpret_cast<uconfig *>(mconfig);
+    uconfig *config = static_cast<uconfig *>(mconfig);
 
     config->url = apr_pstrdup(parms->pool, arg);
 
@@ -766,7 +724,7 @@ static const char *set_url(cmd_parms *parms, void *mconfig, char *arg)
 
 static const char *set_file_dir(cmd_parms *parms, void *mconfig, char *arg)
 {
-    uconfig *config = reinterpret_cast<uconfig *>(mconfig);
+    uconfig *config = static_cast<uconfig *>(mconfig);
 
     config->file_dir = apr_pstrdup(parms->pool, arg);
 
@@ -775,7 +733,7 @@ static const char *set_file_dir(cmd_parms *parms, void *mconfig, char *arg)
 
 static const char *set_thumb_dir(cmd_parms *parms, void *mconfig, char *arg)
 {
-    uconfig *config = reinterpret_cast<uconfig *>(mconfig);
+    uconfig *config = static_cast<uconfig *>(mconfig);
 
     config->thumb_dir = apr_pstrdup(parms->pool, arg);
 
@@ -784,7 +742,7 @@ static const char *set_thumb_dir(cmd_parms *parms, void *mconfig, char *arg)
 
 static const char *set_tmp_dir(cmd_parms *parms, void *mconfig, char *arg)
 {
-    uconfig *config = reinterpret_cast<uconfig *>(mconfig);
+    uconfig *config = static_cast<uconfig *>(mconfig);
 
     config->tmp_dir = apr_pstrdup(parms->pool, arg);
 
@@ -793,7 +751,7 @@ static const char *set_tmp_dir(cmd_parms *parms, void *mconfig, char *arg)
 
 static const char *set_lock_dir(cmd_parms *parms, void *mconfig, char *arg)
 {
-    uconfig *config = reinterpret_cast<uconfig *>(mconfig);
+    uconfig *config = static_cast<uconfig *>(mconfig);
 
     config->lock_dir = apr_pstrdup(parms->pool, arg);
 
@@ -802,7 +760,7 @@ static const char *set_lock_dir(cmd_parms *parms, void *mconfig, char *arg)
 
 static const char *set_view_tmpl_path(cmd_parms *parms, void *mconfig, char *arg)
 {
-    uconfig *config = reinterpret_cast<uconfig *>(mconfig);
+    uconfig *config = static_cast<uconfig *>(mconfig);
 
     config->view_tmpl_path = apr_pstrdup(parms->pool, arg);
 
@@ -811,7 +769,7 @@ static const char *set_view_tmpl_path(cmd_parms *parms, void *mconfig, char *arg
 
 static const char *set_download_tmpl_path(cmd_parms *parms, void *mconfig, char *arg)
 {
-    uconfig *config = reinterpret_cast<uconfig *>(mconfig);
+    uconfig *config = static_cast<uconfig *>(mconfig);
 
     config->download_tmpl_path = apr_pstrdup(parms->pool, arg);
 
@@ -820,7 +778,7 @@ static const char *set_download_tmpl_path(cmd_parms *parms, void *mconfig, char
 
 static const char *set_thumb_tmpl_path(cmd_parms *parms, void *mconfig, char *arg)
 {
-    uconfig *config = reinterpret_cast<uconfig *>(mconfig);
+    uconfig *config = static_cast<uconfig *>(mconfig);
 
     config->thumb_tmpl_path = apr_pstrdup(parms->pool, arg);
 
@@ -829,7 +787,7 @@ static const char *set_thumb_tmpl_path(cmd_parms *parms, void *mconfig, char *ar
 
 static const char *set_error_tmpl_path(cmd_parms *parms, void *mconfig, char *arg)
 {
-    uconfig *config = reinterpret_cast<uconfig *>(mconfig);
+    uconfig *config = static_cast<uconfig *>(mconfig);
 
     config->error_tmpl_path = apr_pstrdup(parms->pool, arg);
 
@@ -838,7 +796,7 @@ static const char *set_error_tmpl_path(cmd_parms *parms, void *mconfig, char *ar
 
 static const char *set_max_file_size(cmd_parms *parms, void *mconfig, char *arg)
 {
-    uconfig *config = reinterpret_cast<uconfig *>(mconfig);
+    uconfig *config = static_cast<uconfig *>(mconfig);
 
     config->max_file_size = atoi(arg) * 1024;
 
@@ -847,7 +805,7 @@ static const char *set_max_file_size(cmd_parms *parms, void *mconfig, char *arg)
 
 static const char *set_total_file_size_limit(cmd_parms *parms, void *mconfig, char *arg)
 {
-    uconfig *config = reinterpret_cast<uconfig *>(mconfig);
+    uconfig *config = static_cast<uconfig *>(mconfig);
 
     config->total_file_size_limit = atoi(arg) * 1024;
 
@@ -856,7 +814,7 @@ static const char *set_total_file_size_limit(cmd_parms *parms, void *mconfig, ch
 
 static const char *set_total_file_number_limit(cmd_parms *parms, void *mconfig, char *arg)
 {
-    uconfig *config = reinterpret_cast<uconfig *>(mconfig);
+    uconfig *config = static_cast<uconfig *>(mconfig);
 
     config->total_file_number_limit = atoi(arg);
 
@@ -865,7 +823,7 @@ static const char *set_total_file_number_limit(cmd_parms *parms, void *mconfig,
 
 static const char *set_per_page_item_number(cmd_parms *parms, void *mconfig, char *arg)
 {
-    uconfig *config = reinterpret_cast<uconfig *>(mconfig);
+    uconfig *config = static_cast<uconfig *>(mconfig);
 
     config->per_page_item_number = atoi(arg);
 
